@@ -1,23 +1,17 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2010-2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2010-2022 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
 #ifndef KDSOAPPENDINGCALLWATCHER_H
 #define KDSOAPPENDINGCALLWATCHER_H
 
-#include <QtCore/QObject>
 #include "KDSoapPendingCall.h"
+#include <QtCore/QObject>
 
 /**
  * The KDSoapPendingCallWatcher class provides a convenient way for waiting for
@@ -31,8 +25,8 @@
  *  KDSoapPendingCall pendingCall = client.asyncCall(QLatin1String("MethodName"), message);
  *  KDSoapPendingCallWatcher *watcher = new KDSoapPendingCallWatcher(pendingCall, this);
  *
- *  QObject::connect(watcher, SIGNAL(finished(KDSoapPendingCallWatcher*)),
- *                   this, SLOT(slotFinished(KDSoapPendingCallWatcher*)));
+ *  QObject::connect(watcher, &KDSoapPendingCallWatcher::finished,
+ *                   this, &MyClass::slotFinished);
  * \endcode
  *
  * \note It is not necessary to keep the original KDSoapPendingCall object
@@ -65,7 +59,6 @@ Q_SIGNALS:
 private:
     friend class KDSoapPendingCallPrivate;
 
-    Q_PRIVATE_SLOT(d, void _kd_slotReplyFinished())
     class Private;
     Private *const d;
 };
